@@ -23,8 +23,8 @@ from plotpy.interfaces import (
 from plotpy.styles.base import SymbolParam
 from plotpy.styles.curve import CurveParam
 
-if TYPE_CHECKING:  # pragma: no cover
-    import guidata.dataset.io
+if TYPE_CHECKING:
+    import guidata.io
 
     from plotpy.interfaces import IItemType
     from plotpy.styles.base import ItemParameters
@@ -138,7 +138,7 @@ class CurveItem(QwtPlotCurve):
         """
         if self.plot().get_axis_scale(axis_id) == "log":
             if len(axis_data[axis_data > 0]) == 0:
-                return 0
+                return 0.0
             else:
                 return axis_data[axis_data > 0].min()
         else:
@@ -257,9 +257,7 @@ class CurveItem(QwtPlotCurve):
 
     def serialize(
         self,
-        writer: guidata.dataset.io.HDF5Writer
-        | guidata.dataset.io.INIWriter
-        | guidata.dataset.io.JSONWriter,
+        writer: guidata.io.HDF5Writer | guidata.io.INIWriter | guidata.io.JSONWriter,
     ) -> None:
         """Serialize object to HDF5 writer
 
@@ -274,9 +272,7 @@ class CurveItem(QwtPlotCurve):
 
     def deserialize(
         self,
-        reader: guidata.dataset.io.HDF5Reader
-        | guidata.dataset.io.INIReader
-        | guidata.dataset.io.JSONReader,
+        reader: guidata.io.HDF5Reader | guidata.io.INIReader | guidata.io.JSONReader,
     ) -> None:
         """Deserialize object from HDF5 reader
 
@@ -357,18 +353,44 @@ class CurveItem(QwtPlotCurve):
         Returns:
             tuple: Tuple with two elements: x and y NumPy arrays
         """
+        assert isinstance(self._x, np.ndarray) and isinstance(self._y, np.ndarray)
         return self._x, self._y
 
+    def update_data(self) -> None:
+        """Update curve data with current arrays."""
+        if isinstance(self._x, np.ndarray) and isinstance(self._y, np.ndarray):
+            self._setData(self._x, self._y)
+
+    def dsamp(self, data: np.ndarray) -> np.ndarray:
+        """Downsample data
+
+        Args:
+            data: Data to downsample
+
+        Returns:
+            Downsampled data
+        """
+        if self.param.use_dsamp and self.param.dsamp_factor > 1:
+            return data[:: self.param.dsamp_factor]
+        return data
+
+    def _setData(self, x: np.ndarray, y: np.ndarray) -> None:
+        """Wrapper around QwtPlotCurve.setData() to handle downsampling"""
+        return super().setData(self.dsamp(x), self.dsamp(y))
+
     def set_data(self, x: np.ndarray, y: np.ndarray) -> None:
         """Set curve data
 
         Args:
             x: X data
             y: Y data
+            decimated_data: Set to True if CurveItem X and Y arrays are already set and
+             this method is called to update decimated data (i.e. only update 1/N value
+             with N set in CurveItem.param.decimation).
         """
         self._x = np.array(x, copy=False)
         self._y = np.array(y, copy=False)
-        self.setData(self._x, self._y)
+        self._setData(self._x, self._y)
 
     def is_empty(self) -> bool:
         """Return True if the item is empty
@@ -431,7 +453,8 @@ class CurveItem(QwtPlotCurve):
             p1x = plot.transform(ax, self._x[i + 1])
             p1y = plot.transform(ay, self._y[i + 1])
         distance = seg_dist(QC.QPointF(pos), QC.QPointF(p0x, p0y), QC.QPointF(p1x, p1y))
-        return distance, i, False, None
+        final_index = i // (int(not self.param.use_dsamp) or self.param.dsamp_factor)
+        return distance, final_index, False, None
 
     def get_closest_coordinates(self, x: float, y: float) -> tuple[float, float]:
         """
@@ -480,9 +503,8 @@ class CurveItem(QwtPlotCurve):
         # We assume X is sorted, otherwise we'd need :
         # argmin(abs(x-xc))
         i = self._x.searchsorted(xc)
-        if i > 0:
-            if np.fabs(self._x[i - 1] - xc) < np.fabs(self._x[i] - xc):
-                return self._x[i - 1], self._y[i - 1]
+        if i > 0 and np.fabs(self._x[i - 1] - xc) < np.fabs(self._x[i] - xc):
+            return self._x[i - 1], self._y[i - 1]
         return self._x[i], self._y[i]
 
     def move_local_point_to(
@@ -502,7 +524,7 @@ class CurveItem(QwtPlotCurve):
         x, y = canvas_to_axes(self, pos)
         self._x[handle] = x
         self._y[handle] = y
-        self.setData(self._x, self._y)
+        self._setData(self._x, self._y)
         self.plot().replot()
 
     def move_local_shape(self, old_pos: QC.QPointF, new_pos: QC.QPointF) -> None:
@@ -516,7 +538,7 @@ class CurveItem(QwtPlotCurve):
         ox, oy = canvas_to_axes(self, old_pos)
         self._x += nx - ox
         self._y += ny - oy
-        self.setData(self._x, self._y)
+        self._setData(self._x, self._y)
 
     def move_with_selection(self, delta_x: float, delta_y: float) -> None:
         """Translate the item together with other selected items
@@ -527,7 +549,7 @@ class CurveItem(QwtPlotCurve):
         """
         self._x += delta_x
         self._y += delta_y
-        self.setData(self._x, self._y)
+        self._setData(self._x, self._y)
 
     def update_params(self):
         """Update item parameters (object properties) from datasets"""
