@@ -53,7 +53,7 @@ from plotpy.items import (
 from plotpy.styles.axes import AxesParam, AxeStyleParam, AxisParam, ImageAxesParam
 from plotpy.styles.base import GridParam, ItemParameters
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from typing import IO
 
     from qwt.scale_widget import QwtScaleWidget
@@ -61,7 +61,7 @@ if TYPE_CHECKING:  # pragma: no cover
     from plotpy.plot.manager import PlotManager
 
     TrackableItem = CurveItem | BaseImageItem
-    import guidata.dataset.io
+    import guidata.io
 
 
 @dataclasses.dataclass
@@ -1467,11 +1467,7 @@ class BasePlot(qwt.QwtPlot):
 
     def serialize(
         self,
-        writer: (
-            guidata.dataset.io.HDF5Writer
-            | guidata.dataset.io.INIWriter
-            | guidata.dataset.io.JSONWriter
-        ),
+        writer: guidata.io.HDF5Writer | guidata.io.INIWriter | guidata.io.JSONWriter,
     ) -> None:
         """Serialize object to HDF5 writer
 
@@ -1485,11 +1481,7 @@ class BasePlot(qwt.QwtPlot):
 
     def deserialize(
         self,
-        reader: (
-            guidata.dataset.io.HDF5Reader
-            | guidata.dataset.io.INIReader
-            | guidata.dataset.io.JSONReader
-        ),
+        reader: guidata.io.HDF5Reader | guidata.io.INIReader | guidata.io.JSONReader,
     ) -> None:
         """Deserialize object from HDF5 reader
 
