@@ -32,9 +32,12 @@ from plotpy.mathutils.colormap import (
 )
 from plotpy.styles.base import ItemParameters
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from guidata.dataset import DataSet
 
+    from plotpy.items import BaseImageItem
+    from plotpy.plot import BasePlot
+
 
 def _create_choices(
     dataset: DataSet, item: ImageChoiceItem, value: Any
@@ -82,6 +85,7 @@ class BaseImageParam(DataSet):
         .set_prop("display", hide=GetAttrProp("_hide_colormap"))
         .set_prop("display", size=(LARGE_ICON_WIDTH, LARGE_ICON_HEIGHT))
     )
+    invert_colormap = BoolItem(_("Invert colormap"), default=False)
 
     interpolation = ChoiceItem(
         _("Interpolation"),
@@ -102,13 +106,17 @@ class BaseImageParam(DataSet):
     zformat = StringItem(_("Z-Axis"), default=r"%.1f")
     _end_formats = EndGroup(_("Statistics string formatting"))
 
-    def update_param(self, image):
-        """
+    def update_param(self, image: BaseImageItem) -> None:
+        """Update the parameters from the given image item.
 
-        :param image:
+        Args:
+            image: The image item to update the parameters from.
         """
         self.label = str(image.title().text())
-        self.colormap = image.get_color_map_name()
+        cmap = image.get_color_map()
+        if cmap is not None:
+            self.colormap = cmap.name
+            self.invert_colormap = cmap.invert
         interpolation = image.get_interpolation()
         mode = interpolation[0]
 
@@ -120,19 +128,20 @@ class BaseImageParam(DataSet):
             size = interpolation[1].shape[0]
             self.interpolation = size
 
-    def update_item(self, image):
-        """
+    def update_item(self, image: BaseImageItem) -> None:
+        """Update the given image item from the parameters.
 
-        :param image:
+        Args:
+            image: The image item to update.
         """
         if isinstance(self.alpha_function, LUTAlpha):
             self.alpha_function = self.alpha_function.value
-        plot = image.plot()
+        plot: BasePlot = image.plot()
         if plot is not None:
             plot.blockSignals(True)  # Avoid unwanted calls of update_param
             # triggered by the setter methods below
         image.setTitle(self.label)
-        image.set_color_map(self.colormap)
+        image.set_color_map(self.colormap, self.invert_colormap)
         size = self.interpolation
 
         if size == 0:
@@ -164,6 +173,7 @@ class QuadGridParam(DataSet):
     colormap = ImageChoiceItem(_("Colormap"), _create_choices, default="jet").set_prop(
         "display", hide=GetAttrProp("_hide_colormap")
     )
+    invert_colormap = BoolItem(_("Invert colormap"), default=False)
 
     interpolation = ChoiceItem(
         _("Interpolation"),
@@ -192,23 +202,28 @@ class QuadGridParam(DataSet):
     grid = BoolItem(_("Show grid"), default=False)
     gridcolor = ColorItem(_("Grid lines color"), default="black")
 
-    def update_param(self, image):
-        """
+    def update_param(self, image: BaseImageItem) -> None:
+        """Update the parameters from the given image item.
 
-        :param image:
+        Args:
+            image: The image item to update the parameters from.
         """
         self.label = str(image.title().text())
-        self.colormap = image.get_color_map_name()
+        cmap = image.get_color_map()
+        if cmap is not None:
+            self.colormap = cmap.name
+            self.invert_colormap = cmap.invert
         interp, uflat, vflat = image.interpolate
         self.interpolation = interp
         self.uflat = uflat
         self.vflat = vflat
         self.grid = image.grid
 
-    def update_item(self, image):
-        """
+    def update_item(self, image: BaseImageItem) -> None:
+        """Update the given image item from the parameters.
 
-        :param image:
+        Args:
+            image: The image item to update.
         """
         if isinstance(self.alpha_function, LUTAlpha):
             self.alpha_function = self.alpha_function.value
@@ -217,7 +232,7 @@ class QuadGridParam(DataSet):
             plot.blockSignals(True)  # Avoid unwanted calls of update_param
             # triggered by the setter methods below
         image.setTitle(self.label)
-        image.set_color_map(self.colormap)
+        image.set_color_map(self.colormap, self.invert_colormap)
         image.interpolate = (self.interpolation, self.uflat, self.vflat)
         image.grid = self.grid
         if plot is not None:
